about summary refs log tree commit diff
path: root/locale/programs/localedef.h
diff options
context:
space:
mode:
authorCarlos O'Donell <carlos@redhat.com>2013-10-18 23:41:30 -0400
committerCarlos O'Donell <carlos@redhat.com>2013-10-18 23:44:35 -0400
commit484c12fb1e3664fb434291234ea5787c5e3df4f5 (patch)
tree10c8b18434c01645f5e04d4adab2b61d43376302 /locale/programs/localedef.h
parentde5d4f4c8a426564690197469b0beacfc31a5e35 (diff)
downloadglibc-484c12fb1e3664fb434291234ea5787c5e3df4f5.tar.gz
glibc-484c12fb1e3664fb434291234ea5787c5e3df4f5.tar.xz
glibc-484c12fb1e3664fb434291234ea5787c5e3df4f5.zip
Enhance localedef --list-archive option.
The localedef --list-archive option claims that it can
accept a [file] argument and list the contents of that
archive. The support was never implemented. This patch
adds that support and allows --list-archive to work as
expected. You can now use localedef to list the contents
of arbitrary locale archives by using:
./localedef --list-archive file
Diffstat (limited to 'locale/programs/localedef.h')
-rw-r--r--locale/programs/localedef.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/locale/programs/localedef.h b/locale/programs/localedef.h
index e010c72983..5a05a2e382 100644
--- a/locale/programs/localedef.h
+++ b/locale/programs/localedef.h
@@ -170,7 +170,9 @@ extern int add_locales_to_archive (size_t nlist, char *list[], bool replace);
 /* Removed named locales from archive.  */
 extern int delete_locales_from_archive (size_t nlist, char *list[]);
 
-/* List content of locale archive.  */
-extern void show_archive_content (int verbose) __attribute__ ((noreturn));
+/* List content of locale archive. If FNAME is non-null use that as
+   the locale archive to list, otherwise the default.  */
+extern void show_archive_content (const char *fname,
+				  int verbose) __attribute__ ((noreturn));
 
 #endif /* localedef.h */